indicatortools.Articulation
===========================

.. abjad-lineage:: abjad.tools.indicatortools.Articulation.Articulation

.. autoclass:: abjad.tools.indicatortools.Articulation.Articulation

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.indicatortools.Articulation.Articulation.direction
      ~abjad.tools.indicatortools.Articulation.Articulation.name
      ~abjad.tools.indicatortools.Articulation.Articulation.__copy__
      ~abjad.tools.indicatortools.Articulation.Articulation.__eq__
      ~abjad.tools.indicatortools.Articulation.Articulation.__format__
      ~abjad.tools.indicatortools.Articulation.Articulation.__hash__
      ~abjad.tools.indicatortools.Articulation.Articulation.__illustrate__
      ~abjad.tools.indicatortools.Articulation.Articulation.__ne__
      ~abjad.tools.indicatortools.Articulation.Articulation.__repr__
      ~abjad.tools.indicatortools.Articulation.Articulation.__str__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.indicatortools.Articulation.Articulation.direction
   :noindex:

.. autoattribute:: abjad.tools.indicatortools.Articulation.Articulation.name
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.indicatortools.Articulation.Articulation.__copy__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Articulation.Articulation.__eq__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Articulation.Articulation.__format__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Articulation.Articulation.__hash__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Articulation.Articulation.__illustrate__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Articulation.Articulation.__ne__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Articulation.Articulation.__repr__
   :noindex:

.. automethod:: abjad.tools.indicatortools.Articulation.Articulation.__str__
   :noindex:
